==> jc-1.4.0.tar.gz: javax/naming/TimeLimitExceededException.h <==
// public class javax.naming.TimeLimitExceededException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class f53d170db4545a76 javax_naming_LimitExceededException
// @dep_class fadee18b7599c8d5 javax_naming_NamingException
// @dep_class bef7b1e101eb8c4f javax_naming_TimeLimitExceededException

// header file dependencies
// @dep_header javax_naming_LimitExceededException

#include "javax/naming/LimitExceededException.h"

#ifndef _JC_javax_naming_TimeLimitExceededException_H_
#define _JC_javax_naming_TimeLimitExceededException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_naming_TimeLimitExceededException$sub_refs	_jc_javax_naming_TimeLimitExceededException$sub_refs;
typedef struct _jc_javax_naming_TimeLimitExceededException$sub_nonrefs	_jc_javax_naming_TimeLimitExceededException$sub_nonrefs;
typedef struct _jc_javax_naming_TimeLimitExceededException$refs	_jc_javax_naming_TimeLimitExceededException$refs;
typedef struct _jc_javax_naming_TimeLimitExceededException$nonrefs	_jc_javax_naming_TimeLimitExceededException$nonrefs;
typedef struct _jc_javax_naming_TimeLimitExceededException$object	_jc_javax_naming_TimeLimitExceededException$object;

typedef const struct _jc_javax_naming_TimeLimitExceededException$vmethods	_jc_javax_naming_TimeLimitExceededException$vmethods;
typedef const struct _jc_javax_naming_TimeLimitExceededException$vtable	_jc_javax_naming_TimeLimitExceededException$vtable;
typedef const struct _jc_javax_naming_TimeLimitExceededException$vtype	_jc_javax_naming_TimeLimitExceededException$vtype;

// Constructors
extern void _jc_javax_naming_TimeLimitExceededException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_naming_TimeLimitExceededException$object *);
extern void _jc_javax_naming_TimeLimitExceededException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_naming_TimeLimitExceededException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_javax_naming_TimeLimitExceededException$vmethods {
};

// Vtable
struct _jc_javax_naming_TimeLimitExceededException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_naming_NamingException$vmethods	javax_naming_NamingException;
	_jc_javax_naming_LimitExceededException$vmethods	javax_naming_LimitExceededException;
	_jc_javax_naming_TimeLimitExceededException$vmethods	javax_naming_TimeLimitExceededException;
};

// Vtype
struct _jc_javax_naming_TimeLimitExceededException$vtype {
	_jc_type			type;
	_jc_javax_naming_TimeLimitExceededException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_TimeLimitExceededException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_naming_TimeLimitExceededException$refs {
    _jc_javax_naming_TimeLimitExceededException$sub_refs	javax_naming_TimeLimitExceededException;
    _jc_javax_naming_LimitExceededException$sub_refs	javax_naming_LimitExceededException;
    _jc_javax_naming_NamingException$sub_refs	javax_naming_NamingException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_TimeLimitExceededException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_TimeLimitExceededException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_naming_NamingException$sub_nonrefs	javax_naming_NamingException;
    _jc_javax_naming_LimitExceededException$sub_nonrefs	javax_naming_LimitExceededException;
    _jc_javax_naming_TimeLimitExceededException$sub_nonrefs	javax_naming_TimeLimitExceededException;
};

// Object instance structure
struct _jc_javax_naming_TimeLimitExceededException$object {
	_jc_javax_naming_TimeLimitExceededException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_TimeLimitExceededException$vtype	*vtype;
	_jc_javax_naming_TimeLimitExceededException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_TimeLimitExceededException$vtype _jc_javax_naming_TimeLimitExceededException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_TimeLimitExceededException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_TimeLimitExceededException$class_object;

#endif	/* _JC_javax_naming_TimeLimitExceededException_H_ */

==> jc-1.4.6.tar.gz: javax/naming/TimeLimitExceededException.h <==
// public class javax.naming.TimeLimitExceededException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class f53d170db4545a76 javax_naming_LimitExceededException
// @dep_class fadee18b7599c8d5 javax_naming_NamingException
// @dep_class bef7b1e101eb8c4f javax_naming_TimeLimitExceededException

// header file dependencies
// @dep_header javax_naming_LimitExceededException

#include "javax/naming/LimitExceededException.h"

#ifndef _JC_javax_naming_TimeLimitExceededException_H_
#define _JC_javax_naming_TimeLimitExceededException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_naming_TimeLimitExceededException$sub_refs	_jc_javax_naming_TimeLimitExceededException$sub_refs;
typedef struct _jc_javax_naming_TimeLimitExceededException$sub_nonrefs	_jc_javax_naming_TimeLimitExceededException$sub_nonrefs;
typedef struct _jc_javax_naming_TimeLimitExceededException$refs	_jc_javax_naming_TimeLimitExceededException$refs;
typedef struct _jc_javax_naming_TimeLimitExceededException$nonrefs	_jc_javax_naming_TimeLimitExceededException$nonrefs;
typedef struct _jc_javax_naming_TimeLimitExceededException$object	_jc_javax_naming_TimeLimitExceededException$object;

typedef const struct _jc_javax_naming_TimeLimitExceededException$vmethods	_jc_javax_naming_TimeLimitExceededException$vmethods;
typedef const struct _jc_javax_naming_TimeLimitExceededException$vtable	_jc_javax_naming_TimeLimitExceededException$vtable;
typedef const struct _jc_javax_naming_TimeLimitExceededException$vtype	_jc_javax_naming_TimeLimitExceededException$vtype;

// Constructors
extern void _jc_javax_naming_TimeLimitExceededException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_naming_TimeLimitExceededException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_naming_TimeLimitExceededException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_naming_TimeLimitExceededException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_naming_TimeLimitExceededException$vmethods {
};

// Vtable
struct _jc_javax_naming_TimeLimitExceededException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_naming_NamingException$vmethods	javax_naming_NamingException;
	_jc_javax_naming_LimitExceededException$vmethods	javax_naming_LimitExceededException;
	_jc_javax_naming_TimeLimitExceededException$vmethods	javax_naming_TimeLimitExceededException;
};

// Vtype
struct _jc_javax_naming_TimeLimitExceededException$vtype {
	_jc_type			type;
	_jc_javax_naming_TimeLimitExceededException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_TimeLimitExceededException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_naming_TimeLimitExceededException$refs {
    _jc_javax_naming_TimeLimitExceededException$sub_refs	javax_naming_TimeLimitExceededException;
    _jc_javax_naming_LimitExceededException$sub_refs	javax_naming_LimitExceededException;
    _jc_javax_naming_NamingException$sub_refs	javax_naming_NamingException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_TimeLimitExceededException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_TimeLimitExceededException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_naming_NamingException$sub_nonrefs	javax_naming_NamingException;
    _jc_javax_naming_LimitExceededException$sub_nonrefs	javax_naming_LimitExceededException;
    _jc_javax_naming_TimeLimitExceededException$sub_nonrefs	javax_naming_TimeLimitExceededException;
};

// Object instance structure
struct _jc_javax_naming_TimeLimitExceededException$object {
	_jc_javax_naming_TimeLimitExceededException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_TimeLimitExceededException$vtype	*vtype;
	_jc_javax_naming_TimeLimitExceededException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_TimeLimitExceededException$vtype _jc_javax_naming_TimeLimitExceededException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_TimeLimitExceededException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_TimeLimitExceededException$class_object;

#endif	/* _JC_javax_naming_TimeLimitExceededException_H_ */
